@@ -313,6 +313,9 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 	char seek[33];
 	const char *prefix = NULL;
 	const char *ext;
+#ifdef	WIN32
+	const char *ccp;
+#endif
 	char *cp;
 	bool etcpath = false, etctest = false;
 #ifndef	WIN32
@@ -333,19 +336,19 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 	if(!regprefix)
 		regprefix="";
 
-	cp = (char *)keypath;
-	if(*cp == '~')
+	ccp = keypath;
+	if(*ccp == '~')
 	{
-		++cp;
-		if(*cp == '/')
-			++cp;
-		snprintf(path, sizeof(path), CAPE_REGISTRY_USERSETTINGS "/%s%s/", regprefix, cp); 
+		++ccp;
+		if(*ccp == '/')
+			++ccp;
+		snprintf(path, sizeof(path), CAPE_REGISTRY_USERSETTINGS "/%s%s/", regprefix, ccp); 
 	}
 	else
 	{
-		if(*cp == '/')
-			++cp;
-		snprintf(path, sizeof(path), CAPE_REGISTRY_APPLICATIONS "/%s%s/", regprefix, cp);
+		if(*ccp == '/')
+			++ccp;
+		snprintf(path, sizeof(path), CAPE_REGISTRY_APPLICATIONS "/%s%s/", regprefix, ccp);
 	}
 
 	cp = path;
@@ -390,11 +393,11 @@ void Keydata::loadPrefix(const char *pre, const char *keypath)
 	// windows will not support subdir .ini tree; now if not in
 	// registry, then assume unavailable
 
-	cp = strchr(keypath + 3, '/');
-	if(cp)
-		cp = strchr(cp, '/');
+	ccp = strchr(keypath + 3, '/');
+	if(ccp)
+		ccp = strchr(ccp, '/');
 
-	if(cp)
+	if(ccp)
 		return;
 
 	if(*keypath == '~')
